<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>O aplikácií</translation>
    </message>
    <message>
        <location filename="../about.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="48"/>
        <source>Lightweight file manager</source>
        <translation>Ľahký správca súborov</translation>
    </message>
    <message>
        <location filename="../about.ui" line="122"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>Programovanie:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="144"/>
        <source>PCManFM-Qt File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>Správca súborov PCManFM-Qt

Autorské práva © 2009 - 2014 洪任諭 (Hong Jen Yee)

Táto aplikácia je slobodný software, môžete ho šíriť a/alebo
upravovať za podmienok stanovených v GNU - všeobecná 
verejná licencia vydaná nadáciou Free Software Foundation, 
buď verzia 2 alebo akákoľvek neskoršia. 

Táto aplikácia je šírená v nádeji, že bude užitočná, 
ale BEZ AKEJKOĽVEK ZÁRUKY, bez záruky predpokladanej 
PREDAJNOSTI alebo VHODNOSTI PRE KONKRÉTNY ÚČEL. 
Podrobnosti nájdete vo všeobecnej verejnej licencii GNU. 

Spoločne s touto aplikáciou by ste mali obdržať aj kópiu
licencie GNU, pokiaľ tomu tak nie je, napíšte do nadácie Free Software 
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</translation>
    </message>
    <message>
        <location filename="../about.ui" line="113"/>
        <source>Authors</source>
        <translation>Autori</translation>
    </message>
    <message>
        <location filename="../about.ui" line="58"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt&quot;&gt;https://github.com/lxqt/pcmanfm-qt&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt&quot;&gt;https://github.com/lxqt/pcmanfm-qt&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="74"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wiki: &lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt/wiki&quot;&gt;https://github.com/lxqt/pcmanfm-qt/wiki&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wiki: &lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt/wiki&quot;&gt;https://github.com/lxqt/pcmanfm-qt/wiki&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="135"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../autorun.ui" line="14"/>
        <source>Removable medium is inserted</source>
        <translation>Vložte vymeniteľné médium</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="33"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;Je vložené vymeniteľné médium&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="40"/>
        <source>Type of medium:</source>
        <translation>Typ média:</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="47"/>
        <source>Detecting...</source>
        <translation>Zisťovanie...</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="56"/>
        <source>Please select the action you want to perform:</source>
        <translation>Vybrať akciu, ktorá má byť vykonaná:</translation>
    </message>
</context>
<context>
    <name>BulkRenameDialog</name>
    <message>
        <location filename="../bulk-rename.ui" line="6"/>
        <source>Bulk Rename</source>
        <translation>Hromadné premenovanie</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="47"/>
        <source># will be replaced by numbers starting with:</source>
        <translation># bude nahradené číslami začínajúcimi od:</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="80"/>
        <source>Pad numbers with zero if possible</source>
        <translation>Ak je to možné zarovnaj čísla nulami</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="87"/>
        <source>Use localized numbers</source>
        <translation>Zobraziť lokalizovanú podobu čísiel</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="27"/>
        <source>Rename selected files to:</source>
        <translation>Premenovať označené súbory na:</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="40"/>
        <source>Name#</source>
        <translation>Názov#</translation>
    </message>
</context>
<context>
    <name>ConnectServerDialog</name>
    <message>
        <location filename="../connect.ui" line="14"/>
        <source>Connect to remote server</source>
        <translation>Pripojiť k vzdialenému serveru</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="23"/>
        <source>Anonymous &amp;login</source>
        <translation>Anonymné prih&amp;lásenie</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="36"/>
        <source>Login as &amp;user:</source>
        <translation>Prihlásiť sa ako &amp;užívateľ:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="65"/>
        <source>Specify remote folder to connect</source>
        <translation>Zadajte vzdialený priečinok, do ktorého sa chcete pripojiť</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="72"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="79"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="86"/>
        <source>Path:</source>
        <translation>Umiestnenie:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="96"/>
        <source>Host:</source>
        <translation>Stroj:</translation>
    </message>
</context>
<context>
    <name>DesktopEntryDialog</name>
    <message>
        <location filename="../desktopentrydialog.ui" line="14"/>
        <source>Create Launcher</source>
        <translation>Vytvoriť spúšťač</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="38"/>
        <source>Name:</source>
        <translation>Meno:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="45"/>
        <source>Specific name of this launcher.</source>
        <translation>Konkrétny názov tohoto spúšťača.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="58"/>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="65"/>
        <source>A short description or generic name, like &quot;Web Browser&quot; or &quot;Home Directory&quot;.

It can be left empty.</source>
        <translation>Krátky popis, poprípade všeobecné meno. Napríklad &quot;Webový prehliadač&quot; alebo &quot;Domáci
Priečinok&quot;

Nepovinná položka.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="77"/>
        <source>Comment:</source>
        <translation>Komentár:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="84"/>
        <source>A short comment.

It can be left empty.</source>
        <translation>Krátky komentár.

Nepovinná položka.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="96"/>
        <source>Command:</source>
        <translation>Príkaz:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="112"/>
        <location filename="../desktopentrydialog.ui" line="143"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="121"/>
        <source>Icon:</source>
        <translation>Ikona:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="130"/>
        <source>Icon to display in file manager, menus, etc.</source>
        <translation>Ikona spúšťača.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="152"/>
        <location filename="../desktopentrydialog.ui" line="162"/>
        <source>Run in terminal?</source>
        <translation>Spustiť v terminále?</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="155"/>
        <source>Terminal:</source>
        <translation>Terminál:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="165"/>
        <source>Whether the launched program should run in a terminal window.</source>
        <translation>Spustiť program v okne terminálu?</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="169"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="174"/>
        <source>Yes</source>
        <translation>Áno</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="182"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="189"/>
        <source>Whether this is a link or executes a command.</source>
        <translation>Ide o odkaz alebo príkaz na spustenie?</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="193"/>
        <source>Application</source>
        <translation>Aplikácia</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="198"/>
        <source>Link</source>
        <translation>Odkaz</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="206"/>
        <source>Categories:</source>
        <translation>Kategórie:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="213"/>
        <source>Semicolon separated categories in which the entry should be shown if it is used by the DE&apos;s main menu (e.g., when put inside ~/.local/share/applications).

It is needed only when you want to use the created file in the main menu. Otherwise, you could leave it empty.

Examples: AudioVideo, Audio, Video, Development, Education, Game, Graphics, Network, Office, Settings, System, Utility, Qt.</source>
        <translation>Jednotlivé kategórie oddeľte bodkočiarkou. Podľa týchto údajov systém zobrazí v kategóriách hlavnej ponuky v prípade, že bude spúšťač do hlavnej ponuky zaradený (ak ho napr. uložíte do ~/.local/share/application).

Kategórie sú potrebné len ak si prajete používať tento spúšťač v hlavnej ponuky.

Príklady: AudioVideo, Audio, Video, Development, Education, Game, Graphics, Network, Office, Settings, System, Utility, Qt.</translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../desktop-folder.ui" line="14"/>
        <source>Form</source>
        <translation>Formulár</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="23"/>
        <source>Desktop</source>
        <translation>Pracovná plocha</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="29"/>
        <source>Desktop folder:</source>
        <translation>Priečinok pracovnej plochy:</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="36"/>
        <source>Image file</source>
        <translation>Súbor s obrázkom</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="42"/>
        <source>Folder path</source>
        <translation>Umiestnenie priečinka</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="49"/>
        <source>&amp;Browse</source>
        <translation>&amp;Prehľadávať</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktop-preferences.ui" line="14"/>
        <source>Desktop Preferences</source>
        <translation>Predvoľby pracovnej plochy</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="338"/>
        <location filename="../desktop-preferences.ui" line="344"/>
        <source>Background</source>
        <translation>Pozadie</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="385"/>
        <source>Wallpaper mode:</source>
        <translation>Režim obrázku pozadia:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="408"/>
        <source>Wallpaper image file:</source>
        <translation>Súbor s obrázkom pozadia:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="350"/>
        <source>Select background color:</source>
        <translation>Vybrať farbu pozadia:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="417"/>
        <source>Image file</source>
        <translation>Súbor s obrázkom</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="423"/>
        <source>Image file path</source>
        <translation>Umiestnenie súboru s obrázkom</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="430"/>
        <source>&amp;Browse</source>
        <translation>&amp;Prechádzať</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="30"/>
        <source>Icons</source>
        <translation>Ikony</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="36"/>
        <source>Icon size:</source>
        <translation>Veľkosť ikon:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="49"/>
        <source>Label Text</source>
        <translation>Text štítku</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="113"/>
        <source>Select shadow color:</source>
        <translation>Farba tieňa:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="61"/>
        <source>Select font:</source>
        <translation>Font:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="24"/>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="87"/>
        <source>Select text color:</source>
        <translation>Farba textu:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="136"/>
        <source>Spacing</source>
        <translation>Rozostupy</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="152"/>
        <source>Minimum item margins:</source>
        <translation>Najmenšie okraje položiek:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="189"/>
        <source>3 px by default.</source>
        <translation>Pôvodné nastavenie: 3 px.</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="176"/>
        <location filename="../desktop-preferences.ui" line="192"/>
        <location filename="../desktop-preferences.ui" line="237"/>
        <location filename="../desktop-preferences.ui" line="249"/>
        <location filename="../desktop-preferences.ui" line="275"/>
        <location filename="../desktop-preferences.ui" line="287"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="205"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="172"/>
        <source>1 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>Pôvodné nastavenie: 1 px.
Navyše je rezervované miesto pre 3 riadky textu.</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="145"/>
        <source>Lock</source>
        <translation>Uzamknúť</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="230"/>
        <source>Margins of work area:</source>
        <translation>Okraje pracovnej oblasti:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="303"/>
        <source>By default, desktop folders will be opened in PCManFM-Qt if they
are left clicked, even when it is not the default file manager.</source>
        <translation>Štandardne sa otvoria priečinky na pracovnej ploche v PCManFM-Qt, ak
kliknete ľavým tlačidlom myši, aj keď nejde o predvoleného správcu súborov.</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="307"/>
        <source>Open desktop folders in default file manager by left clicking</source>
        <translation>Kliknutím ľavým tlačítkom myši otvoríte priečinky na ploche v predvolenom správcovi súborov</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="314"/>
        <source>Make all items stick to their positions</source>
        <translation>Zamknúť poradie ikon na pracovnej ploche</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="373"/>
        <source>Wallpaper</source>
        <translation>Tapeta na ploche</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="439"/>
        <source>Transform image based on EXIF data</source>
        <translation>Transformovať obrázok na základe dát EXIF</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="446"/>
        <source>Individual wallpaper for each monitor</source>
        <translation>Rôzne tapety pre každý monitor</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="473"/>
        <source>Slide Show</source>
        <translation>Prezentovať</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="479"/>
        <source>Enable Slide Show</source>
        <translation>Meniť obrázky na pozadí</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="491"/>
        <source>Wallpaper image folder:</source>
        <translation>Priečinok s tapetami:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="498"/>
        <source>Browse</source>
        <translation>Prechádzať</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="505"/>
        <source> hour(s)</source>
        <translation> .hodin</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="515"/>
        <source>and</source>
        <translation>a</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="528"/>
        <source>Intervals less than 5min will be ignored</source>
        <translation>Interval kratší ako 5 minúť bude ignorovaný</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="531"/>
        <source>Interval:</source>
        <translation>Interval:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="538"/>
        <source> minute(s)</source>
        <translation> .minúty</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="564"/>
        <source>Wallpaper folder</source>
        <translation>Priečinok s tapetami</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="587"/>
        <source>Randomize the slide show</source>
        <translation>Náhodné poradie, prezentácia</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="620"/>
        <source>Visible Shortcuts</source>
        <translation>Viditeľné skratky</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="626"/>
        <source>Home</source>
        <translation>Domovský priečinok</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="637"/>
        <source>Trash</source>
        <translation>Kôš</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="648"/>
        <source>Computer</source>
        <translation>Môj počítač</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="659"/>
        <source>Network</source>
        <translation>Sieť</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="614"/>
        <source>Advanced</source>
        <translation>Pokročilé</translation>
    </message>
</context>
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Skryté skratky</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="21"/>
        <source>Shortcut</source>
        <translation>Skratka</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="26"/>
        <source>Action</source>
        <translation>Činnosť</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="31"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Focus view, clear filter bar</source>
        <translation>Zamerať pohľad, vymazať pole filtru</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Ctrl+Esc</source>
        <translation>Ctrl+Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="42"/>
        <source>Focus side-pane</source>
        <translation>Zaostriť bočný panel</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="50"/>
        <location filename="../shortcuts.ui" line="58"/>
        <source>Focus path entry</source>
        <translation>Zadajte cestu zaostrenia</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <source>Alt+D</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Ctrl+Tab</source>
        <translation>Ctrl+Tab</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="66"/>
        <location filename="../shortcuts.ui" line="82"/>
        <source>Next tab</source>
        <translation>Ďalšia karta</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Ctrl+Shift+Tab</source>
        <translation>Ctrl+Shift+Tab</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="74"/>
        <location filename="../shortcuts.ui" line="90"/>
        <source>Previous tab</source>
        <translation>Predchádzajúca karta</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <source>Ctrl+PageDown</source>
        <translation>Ctrl+PageDown</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Ctrl+PageUp</source>
        <translation>Ctrl+PageUp</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>Ctrl+Number</source>
        <translation>Ctrl+Číslo</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="98"/>
        <location filename="../shortcuts.ui" line="106"/>
        <source>Jump to tab</source>
        <translation>Prejsť na kartu</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="103"/>
        <source>Alt+Number</source>
        <translation>Alt+číslo</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="111"/>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="114"/>
        <source>Go up</source>
        <translation>Ísť hore</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="119"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="122"/>
        <source>Search dialog</source>
        <translation>Dialógové okno hľadania</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="127"/>
        <source>Shift+Insert</source>
        <translation>Shift+Insert</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="130"/>
        <source>Paste into transient filter bar</source>
        <translation>Vložiť do poľa dočasného filtru</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="135"/>
        <source>Drop+Shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="143"/>
        <source>Drop+Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="151"/>
        <source>Drop+Shift+Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="138"/>
        <source>Move file on dropping</source>
        <translation>Po pustení presunúť súbor</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="146"/>
        <source>Copy file on dropping</source>
        <translation>Po pustení kopírovať súbor</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="154"/>
        <source>Make a symlink on dropping</source>
        <translation>Po pustení vytvoriť symbolický odkaz</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main-win.ui" line="14"/>
        <source>File Manager</source>
        <translation>Správca súborov</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="81"/>
        <source>Recent F&amp;iles</source>
        <translation>&amp;Nedávne súbory</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="139"/>
        <source>&amp;Toolbars</source>
        <translation>Pruh nás&amp;trojov</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="146"/>
        <source>Path &amp;Bar</source>
        <translation>&amp;Pruh popisu umiestnenia</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="153"/>
        <source>&amp;Filtering</source>
        <translation>&amp;Filtrovanie</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="228"/>
        <source>&amp;Tools</source>
        <translation>&amp;Nástroje</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="287"/>
        <source>Go &amp;Up</source>
        <translation>Hor&amp;e</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="290"/>
        <source>Go Up</source>
        <translation>Hore</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="293"/>
        <source>Alt+Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="302"/>
        <source>&amp;Home</source>
        <translation>&amp;Domov</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="305"/>
        <source>Alt+Home</source>
        <translation>Alt+Home</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="314"/>
        <source>&amp;Reload</source>
        <translation>&amp;Načítať znova</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="317"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="326"/>
        <source>Go</source>
        <translation>Prejsť na</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="335"/>
        <source>Quit</source>
        <translation>Ukončiť</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="344"/>
        <source>&amp;About</source>
        <translation>O &amp;aplikácií</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="353"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nové okno</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="356"/>
        <source>New Window</source>
        <translation>Nové okno</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="359"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="367"/>
        <source>Show &amp;Hidden</source>
        <translation>Zobraziť &amp;skryté</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="370"/>
        <source>Ctrl+H</source>
        <translation>Strg+H</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="379"/>
        <source>&amp;Computer</source>
        <translation>P&amp;očítač</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="388"/>
        <source>&amp;Trash</source>
        <translation>&amp;Kôš</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="393"/>
        <source>&amp;Network</source>
        <translation>&amp;Sieť</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="402"/>
        <source>&amp;Desktop</source>
        <translation>&amp;Plocha</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="411"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>&amp;Pridať do záložiek</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="416"/>
        <source>&amp;Applications</source>
        <translation>&amp;Aplikácie</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="421"/>
        <source>Reload</source>
        <translation>Znovu načítať</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="429"/>
        <source>&amp;Icon View</source>
        <translation>&amp;Ikony</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="437"/>
        <source>&amp;Compact View</source>
        <translation>&amp;Kompaktné</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="445"/>
        <source>&amp;Detailed List</source>
        <translation>&amp;Zoznam s podrobnosťami</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="453"/>
        <source>&amp;Thumbnail View</source>
        <translation>&amp;Náhľad</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="462"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Vystrihnúť</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="465"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="474"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovať</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="477"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="486"/>
        <source>&amp;Paste</source>
        <translation>&amp;Prilepiť</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="489"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="494"/>
        <source>Select &amp;All</source>
        <translation>&amp;Vybrať všetko</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="497"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="502"/>
        <source>De&amp;select All</source>
        <translation>Zrušiť označ&amp;enie</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="505"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="510"/>
        <source>Pr&amp;eferences</source>
        <translation>&amp;Predvoľby</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="518"/>
        <source>&amp;Ascending</source>
        <translation>&amp;Vzostupne</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="526"/>
        <source>&amp;Descending</source>
        <translation>&amp;Zostupne</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="534"/>
        <source>&amp;By File Name</source>
        <translation>&amp;Podľa názvu súboru</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="542"/>
        <source>By &amp;Modification Time</source>
        <translation>Podľa času poslednej z&amp;meny</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="550"/>
        <source>By C&amp;reation Time</source>
        <translation>Podľa času vy&amp;tvorenia</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="558"/>
        <source>By Deletio&amp;n Time</source>
        <translation>&amp;Podľa okamihu zmazania</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="566"/>
        <source>By File &amp;Type</source>
        <translation>Podľa &amp;typu súboru</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="574"/>
        <source>By &amp;Owner</source>
        <translation>&amp;Podľa vlastníka</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="582"/>
        <source>By &amp;Group</source>
        <translation>&amp;Podľa skupiny</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="590"/>
        <source>&amp;Folder First</source>
        <translation>&amp;Priečinky na vrchu</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="598"/>
        <source>&amp;Hidden Last</source>
        <translation>Skryté súbory na konci</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="879"/>
        <source>Shift+F2</source>
        <translation>Shift+F2</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="963"/>
        <source>Preserve Settings Recursively from &amp;Here</source>
        <translation>Použiť tieto nastavenia &amp;rekurzívne od tohoto priečinka</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="968"/>
        <source>&amp;Go to Source of Inherited Settings</source>
        <translation>Choď na priečinok so zdrojovými nastaveniami</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="973"/>
        <source>&amp;Remove Settings of Nonexistent Folders</source>
        <translation>&amp;Odstráň nastavenia pre neexistujúce priečinky</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="981"/>
        <source>&amp;Clear</source>
        <translation>&amp;Vyčistiť</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="651"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="700"/>
        <source>&amp;Case Sensitive</source>
        <translation>&amp;Rozlišovať malé/veľké písmena</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="708"/>
        <source>By File &amp;Size</source>
        <translation>Podľa veľko&amp;sti súboru</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="713"/>
        <source>&amp;Close Window</source>
        <translation>&amp;Zavrieť okno</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="716"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="734"/>
        <source>Open Tab in &amp;Root Instance</source>
        <translation>Otvoriť záložku ako &amp;Root</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="748"/>
        <source>&amp;Folder</source>
        <translation>&amp;Priečinok</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="760"/>
        <source>&amp;Blank File</source>
        <translation>&amp;Prázdny súbor</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="847"/>
        <source>Preserve Settings for &amp;This Folder</source>
        <translation>Ulož nastavenia pre &amp;tento priečinok</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="884"/>
        <source>&amp;Show/Focus Filter Bar</source>
        <translation>&amp;Zobraziť/skryť lištu filtrovania</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="887"/>
        <source>Show Filter Bar</source>
        <translation>Zobraziť lištu filtrovania</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="890"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="898"/>
        <source>S&amp;plit View</source>
        <translation>&amp;Zdieľať pohľad</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="901"/>
        <source>Split View</source>
        <translation>Rozdelené zobrazenie</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="904"/>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="909"/>
        <source>&amp;Copy Full Path</source>
        <translation>&amp;Skopírovať celý popis umiestnenia</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="912"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="923"/>
        <source>Show Thumb&amp;nails</source>
        <translation>&amp;Zobraziť náhľady</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="926"/>
        <source>Show Thumbnails</source>
        <translation>Zobraziť náhľady</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="934"/>
        <source>S&amp;ide Pane</source>
        <translation>&amp;Bočný panel</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="937"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="942"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>Skryté &amp;Skratky</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="947"/>
        <source>Open Tab in &amp;Admin Mode</source>
        <translation>Otvoriť kartu v &amp;režime Správcu</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="952"/>
        <location filename="../main-win.ui" line="955"/>
        <source>Create Launcher</source>
        <translation>Vytvoriť spúšťač</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="782"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="787"/>
        <source>&amp;Clear All Filters</source>
        <translation>&amp;Zrušiť všetky filtre</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="790"/>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="799"/>
        <source>Close &amp;previous tabs</source>
        <translation>&amp;Zatvoriť predchádzajúce karty</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="808"/>
        <source>Close &amp;next tabs</source>
        <translation>&amp;Zatvoriť následujúce karty</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="852"/>
        <source>Connect to &amp;Server</source>
        <translation>&amp;Pripojiť k serveru</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="860"/>
        <source>&amp;Location</source>
        <translation>&amp;Umiestnenie</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="868"/>
        <source>&amp;Path Buttons</source>
        <translation>&amp;Tlačítka popisu umiestnení</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="873"/>
        <source>&amp;Bulk Rename</source>
        <translation>&amp;Hromadné premenovanie</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="876"/>
        <source>Bulk Rename</source>
        <translation>Hromadné premenovanie</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="813"/>
        <source>Close &amp;other tabs</source>
        <translation>&amp;Zatvoriť ostatné karty</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="779"/>
        <source>Permanent &amp;filter bar</source>
        <translation>Trvalé&amp;lišta filtrovania</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="821"/>
        <source>&amp;Menu bar</source>
        <translation>&amp;Panel ponúk</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="824"/>
        <source>Menu bar</source>
        <translation>Panel ponúk</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="827"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="836"/>
        <location filename="../main-win.ui" line="839"/>
        <source>Menu</source>
        <translation>Ponuka</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="607"/>
        <source>New &amp;Tab</source>
        <translation>&amp;Nová karta</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="160"/>
        <source>&amp;Customized View Settings</source>
        <translation>&amp;Vlastné nastavenie zobrazenia</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="610"/>
        <source>New Tab</source>
        <translation>Nová karta</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="613"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="622"/>
        <source>Go &amp;Back</source>
        <translation>&amp;Späť</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="625"/>
        <source>Go Back</source>
        <translation>Späť</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="628"/>
        <source>Alt+Left</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="637"/>
        <source>Go &amp;Forward</source>
        <translation>&amp;Dopredu</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="640"/>
        <source>Go Forward</source>
        <translation>Dopredu</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="643"/>
        <source>Alt+Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="648"/>
        <source>&amp;Invert Selection</source>
        <translation>&amp;Prevrátiť výber</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="660"/>
        <source>&amp;Delete</source>
        <translation>O&amp;dstrániť</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="663"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="668"/>
        <source>&amp;Rename</source>
        <translation>P&amp;remenovať</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="671"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="676"/>
        <source>C&amp;lose Tab</source>
        <translation>&amp;Zavrieť kartu</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="679"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="684"/>
        <source>File &amp;Properties</source>
        <translation>&amp;Vlastnosti súboru</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="687"/>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="692"/>
        <source>&amp;Folder Properties</source>
        <translation>Vlastnosti &amp;priečinka</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="721"/>
        <source>Edit Bookmarks</source>
        <translation>Upraviť záložky</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="726"/>
        <source>Open &amp;Terminal</source>
        <translation>&amp;Otvoriť terminál</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="729"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="739"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>&amp;Upraviť záložky</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="751"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="763"/>
        <source>Ctrl+Alt+N</source>
        <translation>Ctrl+Alt+N</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="768"/>
        <source>&amp;Find Files</source>
        <translation>&amp;Nájsť súbory</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="771"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="70"/>
        <source>&amp;File</source>
        <translation>&amp;Súbor</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="74"/>
        <source>C&amp;reate New</source>
        <translation>&amp;Vytvoriť nový</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="98"/>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="105"/>
        <location filename="../main-win.ui" line="129"/>
        <source>&amp;View</source>
        <translation>&amp;Zobraziť</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="109"/>
        <source>&amp;Sorting</source>
        <translation>&amp;Zoradiť</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="185"/>
        <source>&amp;Edit</source>
        <translation>Úp&amp;ravy</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="204"/>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Záložky</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="211"/>
        <source>&amp;Go</source>
        <translation>&amp;Ísť na</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="253"/>
        <source>Main Toolbar</source>
        <translation>Hlavná ponuka nástrojov</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>Name of configuration profile</source>
        <translation>Názov profilu nastavení</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>PROFILE</source>
        <translation>PROFIL</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="189"/>
        <source>Run PCManFM-Qt as a daemon</source>
        <translation>Run PCManFM-Qt na pozadí</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="192"/>
        <source>Quit PCManFM-Qt</source>
        <translation>Ukončiť PCManFM-Qt</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="195"/>
        <source>Launch desktop manager</source>
        <translation>Spustiť správcu plochy</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="198"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>Ak je spustený, vypnúť správcu plochy</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="201"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation>Otvoriť dialóg predvolieb plochy na stránke, ktorej názov bol zadaný</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="201"/>
        <location filename="../application.cpp" line="216"/>
        <source>NAME</source>
        <translation>NAZOV</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="204"/>
        <source>Open new window</source>
        <translation>Otvoriť nové okno</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="207"/>
        <source>Open Find Files utility</source>
        <translation>Otvoriť nástroj na hľadanie súborov</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="210"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>Nastaviť pozadie plochy ze SÚBORU s obrázkom</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="210"/>
        <source>FILE</source>
        <translation>SÚBOR</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="213"/>
        <source>MODE</source>
        <translation>REŽIM</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="213"/>
        <source>Set mode of desktop wallpaper. MODE=(%1)</source>
        <translation>Nastaviť režim obrázku na pozadí plochy. MODE=(%1)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="216"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation>Otvoriť dialóg predvolieb na stránke, ktorej bol zadaný názov</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="219"/>
        <source>Files or directories to open</source>
        <translation>Súbory alebo zložky na otvorenie</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="219"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FILE1, FILE2,...]</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="648"/>
        <location filename="../application.cpp" line="653"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="653"/>
        <source>Terminal emulator is not set.</source>
        <translation>Emulátor terminálu nie je nastavený.</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../autorundialog.cpp" line="44"/>
        <source>Open in file manager</source>
        <translation>Otvoriť v správcovi súborov</translation>
    </message>
    <message>
        <location filename="../autorundialog.cpp" line="138"/>
        <source>Removable Disk</source>
        <translation>Vymeniteľné dátové médium</translation>
    </message>
</context>
<context>
    <name>PCManFM::ConnectServerDialog</name>
    <message>
        <location filename="../connectserverdialog.cpp" line="9"/>
        <source>SSH</source>
        <translation>SSH</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="10"/>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="11"/>
        <source>WebDav</source>
        <translation>WebDav</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="12"/>
        <source>Secure WebDav</source>
        <translation>Zabezpečený WebDav</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="13"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="14"/>
        <source>HTTPS</source>
        <translation>HTTPS</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopEntryDialog</name>
    <message>
        <location filename="../desktopentrydialog.cpp" line="35"/>
        <source>Command:</source>
        <translation>Príkaz:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="36"/>
        <source>The command to execute.</source>
        <translation>Tento príkaz spustím.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="39"/>
        <source>URL:</source>
        <translation>URL adresa:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="40"/>
        <source>The URL to access.</source>
        <translation>Túto URL adresu orvorím.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="67"/>
        <source>Select an icon</source>
        <translation>Vybrať ikonu</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="69"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Obrázky (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="91"/>
        <source>Select an executable file</source>
        <translation>Vybrať spustiteľný súbor</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="99"/>
        <source>Select a file</source>
        <translation>Vybrať súbor</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="52"/>
        <source>Fill with background color only</source>
        <translation>Iba vyplniť farbou pozadie</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="53"/>
        <source>Stretch to fill the entire screen</source>
        <translation>Roztiahnuť aby vyplnilo celú obrazovku</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="54"/>
        <source>Stretch to fit the screen</source>
        <translation>Prispôsobiť obrazovke</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="55"/>
        <source>Center on the screen</source>
        <translation>Vystrediť</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="56"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>Obrázky vedľa seba</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="57"/>
        <source>Zoom the image to fill the entire screen</source>
        <translation>Zväčšiť obrázok tak, aby vyplnil obrazovku</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="264"/>
        <source>Select Wallpaper</source>
        <translation>Vybrať tapetu plochy</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="268"/>
        <source>Image Files</source>
        <translation>Obrázkové súbory</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="310"/>
        <source>Select Wallpaper Folder</source>
        <translation>Vybrať priečinok s tapetami</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../desktopwindow.cpp" line="303"/>
        <source>Trash (One item)</source>
        <translation>Kôš (1 položka)</translation>
    </message>
    <message numerus="yes">
        <location filename="../desktopwindow.cpp" line="306"/>
        <source>Trash (%Ln items)</source>
        <translation>
            <numerusform>Kôš (%Ln položka)</numerusform>
            <numerusform>Kôš (%Ln položky)</numerusform>
            <numerusform>Kôš (%Ln položiek)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="310"/>
        <source>Trash (Empty)</source>
        <translation>Koš (prázdny)</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="345"/>
        <source>Computer</source>
        <translation>Môj počítač</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="359"/>
        <source>Network</source>
        <translation>Sieť</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="997"/>
        <source>Open</source>
        <translation>Otvoriť</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1003"/>
        <location filename="../desktopwindow.cpp" line="1043"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>&amp;Pripnúť v aktuálnej polohe</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1011"/>
        <source>Empty Trash</source>
        <translation>Vyprázdniť kôš</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1070"/>
        <source>Hide Desktop Items</source>
        <translation>Skryť zástupcu</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1076"/>
        <source>Create Launcher</source>
        <translation>Vytvoriť spúšťač</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1079"/>
        <source>Desktop Preferences</source>
        <translation>Nastavenia pracovnej plochy</translation>
    </message>
</context>
<context>
    <name>PCManFM::FilterBar</name>
    <message>
        <location filename="../tabpage.cpp" line="95"/>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
</context>
<context>
    <name>PCManFM::FilterEdit</name>
    <message>
        <location filename="../tabpage.cpp" line="65"/>
        <source>Clear text (Ctrl+K or Esc)</source>
        <translation>Vyčistiť text (Ctrl+K nebo Esc)</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="141"/>
        <source>Root Instance</source>
        <translation>Správcovská (root) inštancia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="742"/>
        <source>Hide menu bar</source>
        <translation>Skryť panel ponuky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>This will hide the menu bar completely, use Ctrl+M to show it again.</source>
        <translation>Týmto bude panel ponuky úplne skrytý. Opätovné ho zobrazíte kombináciou klávesnice Ctrl+M.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1190"/>
        <source>Version: %1</source>
        <translation>Verzia: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="174"/>
        <location filename="../mainwindow.cpp" line="2161"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Presunúť do koša</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="174"/>
        <location filename="../mainwindow.cpp" line="2161"/>
        <source>&amp;Delete</source>
        <translation>&amp;Zmazať</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1997"/>
        <source>Customized View Settings</source>
        <translation>Vlastné nastavenie zobrazenia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2268"/>
        <location filename="../mainwindow.cpp" line="2276"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2276"/>
        <source>Switch user command is not set.</source>
        <translation>Príkaz na prepnutie užívateľa nie je nastavený.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2378"/>
        <source>Cleaning Folder Settings</source>
        <translation>Odstrániť nastavenia priečinkov</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2379"/>
        <source>Do you want to remove settings of nonexistent folders?
They might be useful if those folders are created again.</source>
        <translation>Prajete si odstrániť nastavenia pre neexistujúce priečinky?
Ak ich odstránite, nebudú sa dať použiť pri znovuvytvorení priečinkov.</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="199"/>
        <source>Icon View</source>
        <translation>Zobrazenie s ikonami</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="200"/>
        <source>Compact View</source>
        <translation>Kompaktné zobrazenie</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="201"/>
        <source>Thumbnail View</source>
        <translation>Zobrazenie s náhľadom</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="202"/>
        <source>Detailed List View</source>
        <translation>Zobrazenie zoznamu s podrobnosťami</translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../tabpage.cpp" line="443"/>
        <source>Search Results</source>
        <translation>Výsledky vyhľadávania</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="446"/>
        <source>Applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="450"/>
        <source>Computer</source>
        <translation>Môj počítač</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="453"/>
        <source>Network</source>
        <translation>Sieť</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="456"/>
        <source>Trash</source>
        <translation>Kôš</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="462"/>
        <source>Desktop</source>
        <translation>Pracovná plocha</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="553"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="562"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>Voľné miesto: %1 (celkovo: %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="579"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n položka</numerusform>
            <numerusform>%n položky</numerusform>
            <numerusform>%n položiek</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="581"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform> (%n skrytá)</numerusform>
            <numerusform> (%n skrytých)</numerusform>
            <numerusform> (%n skryté)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="586"/>
        <location filename="../tabpage.cpp" line="789"/>
        <location filename="../tabpage.cpp" line="803"/>
        <source>Link to</source>
        <translation>Odkaz na</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="815"/>
        <source>%n item(s) selected</source>
        <translation>
            <numerusform>vybraná %n položka</numerusform>
            <numerusform>vybraných %n položiek</numerusform>
            <numerusform>vybrané %n položky</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../view.cpp" line="59"/>
        <source>Many files</source>
        <translation>Mnoho súborov</translation>
    </message>
    <message numerus="yes">
        <location filename="../view.cpp" line="60"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>Prajete si otvoriť tento %1 súbor?</numerusform>
            <numerusform>Prajete si otvoriť týchto %1 súborov?</numerusform>
            <numerusform>Prajete si otvoriť tieto %1 súbory?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../view.cpp" line="122"/>
        <source>Open in New T&amp;ab</source>
        <translation>&amp;Otvoriť na novej karte</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="126"/>
        <source>Open in New Win&amp;dow</source>
        <translation>&amp;Otvoriť v novom okne</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="134"/>
        <location filename="../view.cpp" line="152"/>
        <source>Open in Termina&amp;l</source>
        <translation>&amp;Otvoriť v terminále</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="45"/>
        <source>User Interface</source>
        <translation>Užívateľské rozhranie</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="35"/>
        <source>Behavior</source>
        <translation>Správanie</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="50"/>
        <location filename="../preferences.ui" line="642"/>
        <source>Thumbnail</source>
        <translation>Náhľad</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="55"/>
        <source>Volume</source>
        <translation>Zväzok</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="60"/>
        <source>Advanced</source>
        <translation>Pokročilé</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="222"/>
        <source>Select newly created files</source>
        <translation>Vybrať novovytvorené súbory</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="296"/>
        <source>Icons</source>
        <translation>Ikony</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="328"/>
        <source>Size of big icons:</source>
        <translation>Veľkosť veľkých ikon:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="345"/>
        <source>Size of small icons:</source>
        <translation>Veľkosť malých ikôn:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="362"/>
        <source>Size of thumbnails:</source>
        <translation>Veľkosť náhľadov:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="376"/>
        <source>Size of side pane icons:</source>
        <translation>Veľkosť ikôn z bočného pohľadu:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="308"/>
        <source>Icon theme:</source>
        <translation>Vzhľad ikon:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="546"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="559"/>
        <source>Always show the tab bar</source>
        <translation>Vždycky zobraziť panel s kartami</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="566"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>Zobraziť na kartách tlačítko Zavrieť	</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="580"/>
        <source>Remember the size of the last closed window</source>
        <translation>Pamätať si rozmery naposledy zatvoreného okna</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="587"/>
        <source>Default width of new windows:</source>
        <translation>Východzia šírka nových okien:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="601"/>
        <source>Default height of new windows:</source>
        <translation>Východzia šírka nových okien:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="81"/>
        <source>Browsing</source>
        <translation>Prechádzať</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="93"/>
        <source>Open files with single click</source>
        <translation>Otvoriť súbory jednoduchým kliknutím</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="113"/>
        <source>Default view mode:</source>
        <translation>Východzí režim zobrazenia:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="129"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="175"/>
        <source>File Operations</source>
        <translation>Operácie so súbormi</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="181"/>
        <source>Confirm before deleting files</source>
        <translation>Vyžadovať potvrdenie pred zmazaním súboru</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="188"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>Presunúť súbor do koša namiesto zmazania súboru na disku.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="651"/>
        <source>Show thumbnails of files</source>
        <translation>Zobraziť náhľady súborov</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="658"/>
        <source>Only show thumbnails for local files</source>
        <translation>Zobraziť náhľady iba pre súbory nachadzajúcich sa priamo v počítači</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="40"/>
        <source>Display</source>
        <translation>Zobrazenie</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="90"/>
        <source>If this is unchecked, the DE setting will be used.</source>
        <translation>V prípade, že toto nebude vybraté, použije sa nastavenie desktopového prostredia.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="103"/>
        <location filename="../preferences.ui" line="126"/>
        <source>Set to zero to disable auto-selection.</source>
        <translation>Nastavením na nulu deaktivujete automatický výber.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="106"/>
        <source>Delay of auto-selection in single click mode:</source>
        <translation>Oneskorenie automatického výberu v režime jedného kliknutia:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="147"/>
        <source>Open in current tab</source>
        <translation>Otvoriť na aktuálnej karte</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="152"/>
        <source>Open in new tab</source>
        <translation>Otvoriť na novej karte</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="157"/>
        <source>Open in new window</source>
        <translation>Otvoriť v novom okne</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="195"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation>Súbory na vymeniteľných médiach rovno mazať namiesto presúvania do koša</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="202"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation>Vyžadovať potvrdenie pred presunutím do koša</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="209"/>
        <location filename="../preferences.ui" line="409"/>
        <location filename="../preferences.ui" line="419"/>
        <source>Requires application restart to take effect completely</source>
        <translation>Aby sa zmena prejavila, je potrebné aplikáciu zatvoriť a spustiť znovu</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="212"/>
        <source>Launch executable files without prompt</source>
        <translation>Spúšťať spustiteľné súbory bez potvrdenia</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="219"/>
        <source>Renamed files will also be selected</source>
        <translation>Do výberu sa zahrnú aj premenované súbory</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="244"/>
        <source>Number of recent files:</source>
        <translation>Počet posledných súborov:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="325"/>
        <location filename="../preferences.ui" line="335"/>
        <source>Used by Icon View</source>
        <translation>Využívané ikonovým zobrazením</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="342"/>
        <location filename="../preferences.ui" line="352"/>
        <source>Used by Compact View and Detailed List View</source>
        <translation>Využívané v kompaktnom a podrobnom zobrazení</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="359"/>
        <location filename="../preferences.ui" line="369"/>
        <source>Used by Thumbnail View</source>
        <translation>Využívané v zobrazení s náhľadmi</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="389"/>
        <source>User interface</source>
        <translation>Užívateľské rozhranie</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="402"/>
        <source>Treat backup files as hidden</source>
        <translation>Zaobchádzať so záložnými súbormi ako s tými skrytými</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="422"/>
        <source>Show icons of hidden files shadowed</source>
        <translation>Tieňované zobrazenie ikôn skrytých súborov</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="459"/>
        <source>Minimum item margins in icon view:</source>
        <translation>Minimálne okraje položky v zobrazení s ikonami:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="466"/>
        <source>3 px by default.</source>
        <translation>Štandardne sú 3 px.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="469"/>
        <location filename="../preferences.ui" line="493"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="482"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="489"/>
        <source>3 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>Štandardne sú tri pixely. 
Je vyhradené miesto pre tri riadky textu.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="506"/>
        <source>Lock</source>
        <translation>Uzamknúť</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="555"/>
        <source>When unchecked, the tab bar will be shown
only if there are more than one tab.</source>
        <translation>Pokiaľ nie je zaškrtnuté, bude panel kariet zobrazený
iba ak je viac ako jedna karta.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="573"/>
        <source>Switch to newly opened tab</source>
        <translation>Prepnúť na novo otvorenú kartu</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="615"/>
        <source>Reopen last window tabs in a new window</source>
        <translation>Otvoriť karty posledného okna v novom okne</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="665"/>
        <location filename="../preferences.ui" line="677"/>
        <source>The built-in thumbnailer makes thumbnails of images that are supported by Qt.

Usually, most image types are supported. The default size limit is 4 MiB.</source>
        <translation>Program vytvára miniatúry obrázkov podporovaných Qt.
Bežne je väčšina typov obrázkov podporovaná. Predvolená maximálna veľkosť je 4 MiB.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="670"/>
        <source>Image size limit for built-in thumbnailer:</source>
        <translation>Maximálna veľkosť obrázka na vytvorenie náhľadu:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="682"/>
        <location filename="../preferences.ui" line="718"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="698"/>
        <location filename="../preferences.ui" line="710"/>
        <source>If existing, external thumbnailers are used for videos, PDF documents, etc.

A value of -1 means that there is no limit for the file size (the default).</source>
        <translation>Ak existujú externé náhľady pre videá, PDF súbory, atď, použijú sa.

Hodnota -1 určuje neobmedzenú veľkosť súboru na vytvorenie náhľadu (predvolené).</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="703"/>
        <source>File size limit for external thumbnailers:</source>
        <translation>Maximálna veľkosť súboru pre externé miniatúry:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="715"/>
        <source>No limit</source>
        <translation>Bez obmedzenia</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="853"/>
        <source>Examples:&lt;br&gt;For terminal: &lt;i&gt;xterm -e %s&lt;/i&gt;&lt;br&gt;For switching user: &lt;i&gt;lxsudo %s&lt;/i&gt; or &lt;i&gt;lxsudo dbus-run-session -- %s&lt;/i&gt;&lt;br&gt;&lt;i&gt;%s&lt;/i&gt; is the command line you want to execute with terminal or su.&lt;br&gt; Important: Please use lxsudo, sudo alone will wreck permissions of the settings file.</source>
        <translation>Príklady:&lt;br&gt;Pre terminál: &lt;i&gt;xterm -e %s&lt;/i&gt;&lt;br&gt;Pre prepnutie užívateľa: &lt;i&gt;lxsudo %s&lt;/i&gt; alebo &lt;i&gt;lxsudo dbus-run-session -- %s&lt;/i&gt;&lt;br&gt;&lt;i&gt;%s&lt;/i&gt; je príkazový riadok, ktorý chcete vykonať v terminále alebo za pomoci su.&lt;br&gt; Dôležité: použite lxsudo, sudo samotné pokazí oprávnenie na súbore s nastaveniami.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="919"/>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="934"/>
        <source>Maximum search history:</source>
        <translation>Maximálna história vyhľadávania:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="948"/>
        <source>Clear search history</source>
        <translation>Vymazať históriu vyhľadávania</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="983"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Aby sa zmeny prejavili, je potrebné reštartovať aplikáciu.</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="139"/>
        <source>Bookmarks menu:</source>
        <translation>Ponuka záložiek:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="165"/>
        <source>Show folder context menu with Ctrl + right click</source>
        <translation>Ukázať kontextovú ponuku pomocou Ctrl + pravé tlačidlo myši</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="229"/>
        <source>Open folders in new tabs as far as possible</source>
        <translation>Ak je to možné, otvárať priečinky v nových kartách</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="232"/>
        <source>Single window mode</source>
        <translation>Režim jedného okna</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="412"/>
        <source>Always show real file names</source>
        <translation>Vždy zobraziť skutočné názvy súborov</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="429"/>
        <source>Do not show file tooltips</source>
        <translation>Nezobrazovať podrobnosti pri presunutí myši na súbor</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="436"/>
        <source>Disable smooth scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="648"/>
        <source>Needs ffmpegthumbnailer</source>
        <translation>Vyžaduje ffmpegthumbnailer</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="754"/>
        <source>Auto Mount</source>
        <translation>Automatické pripojenie</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="760"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>Pri spúšťaní aplikácii pripojiť všetky zväzky, ktoré sú k dispozícii</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="767"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>Pri vložení/pripojení vymeniteľného média ho automaticky pripojiť</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="774"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>Pri vložení/pripojení vymeniteľného média zobraziť možnosti</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="784"/>
        <source>When removable medium unmounted:</source>
        <translation>Pri odpojení vymeniteľného média:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="790"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation>&amp;Zavrieť kartu obsahujúcu vymeniteľné médium</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="797"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation>&amp;Na príslušnej karte prepnúť do domáceho priečinka</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="824"/>
        <source>Programs</source>
        <translation>Programy</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="833"/>
        <source>Terminal emulator:</source>
        <translation>Emulátor terminálu:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="840"/>
        <source>Switch &amp;user command:</source>
        <translation>&amp;Príkaz na prepnutie užívateľa:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="866"/>
        <source>Archiver in&amp;tegration:</source>
        <translation>&amp;Integrácia správcu archívu:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="889"/>
        <source>Templates</source>
        <translation>Šablóny</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="895"/>
        <source>Show only user defined templates in menu</source>
        <translation>V ponuke zobraziť iba šablóny vytvorené užívateľom</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="902"/>
        <source>Show only one template for each MIME type</source>
        <translation>Zobraziť pre každý MIME typ iba jednu šablónu</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="909"/>
        <source>Run default application after creation from template</source>
        <translation>Po vytvorení zo šablóny spustiť menu aplikácii</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="395"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation>Používať SI desiatkové predpony namiesto IEC dvojkových</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bulkrename.cpp" line="86"/>
        <source>Renaming files...</source>
        <translation>Premenovanie súborov...</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="86"/>
        <source>Abort</source>
        <translation>Prerušiť</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="95"/>
        <source>Warning</source>
        <translation>Varovanie</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="95"/>
        <source>Renaming is aborted.</source>
        <translation>Premenovanie bolo zrušené.</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="121"/>
        <location filename="../bulkrename.cpp" line="124"/>
        <location filename="../tabpage.cpp" line="1142"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="121"/>
        <source>No file could be renamed.</source>
        <translation>Nepodarilo sa pripojiť žiaden súbor.</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="124"/>
        <source>Some files could not be renamed.</source>
        <translation>Niektoré súbory sa nepodarilo pripojiť.</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="1142"/>
        <source>Cannot open as Admin.</source>
        <translation>Nedá sa otvoriť ako správca.</translation>
    </message>
</context>
</TS>
